%define testver		240
%define build_debug     0
%{?_with_debug: %{expand: %%define build_debug 1}}

Name:		blender
Version:	2.41
Release:	%mkrel 5
Summary:	A fully functional 3D modeling/rendering/animation package
Group:		Graphics
Source0:	http://download.blender.org/source/blender-%{version}.tar.gz
Source1: 	blender-wrapper
Source2:	http://download.blender.org/demo/test/test%{testver}.zip
Source11:	%{name}-16x16.png
Source12:	%{name}-32x32.png
Source13:	%{name}-48x48.png
Source14:	icons-%{name}nodri.tar.bz2
Patch0:		blender-2.41-openal-fix.patch
Patch1:		blender-2.41-buildfix.patch
Patch2:		blender-2.41-lib64.patch
Patch3:		blender-2.41-forceyafrayplug.patch
Patch4:		blender-2.41-svg2obj-047.patch
URL:		http://www.blender.org/
License:	GPL
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	scons
BuildRequires:	openal-devel >= 0.0.6-9mdk
BuildRequires:	esound-devel
BuildRequires:	ftgl-devel
BuildRequires:	gettext-devel
BuildRequires:	jpeg-devel
%if %{mdkversion} >= 200610
BuildRequires:	mesaglu-devel
%else
BuildRequires:	MesaGLU-devel
%endif
BuildRequires:	oggvorbis-devel
BuildRequires:	openssl-devel
BuildRequires:	png-devel
BuildRequires:	python-devel >= 2.4
BuildRequires:	SDL-devel
BuildRequires:	smpeg-devel
BuildRequires:	tiff-devel
BuildRequires:	XFree86-devel
BuildRequires:	zlib-devel
Requires:	python-imaging >= 1.1.4
Requires:	yafray

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%if %build_debug
This version is build with debug enabled.
%endif

%prep
%setup -q -n blender -a 2
%patch0 -p1 -b .openal
%patch1 -p1 -b .sconst
%if "%{_lib}" != "lib"
%patch2 -p1 -b .lib64
%endif
%patch3 -p1 -b .yafray
%patch4 -p1 -b .svg2obj047
cp -p SConstruct SConstruct.sse
OPTFLAGS="%{optflags} -ffast-math" \
perl -pi -e \
	'BEGIN { $s = join(", ", map { "'\''$_'\''" } "-funsigned-char", split(" ", $ENV{OPTFLAGS})) } s/extra_flags\s*=\s*\[.*\]$/extra_flags = [ $s ]/' SConstruct
perl -pi -e 's@-O2@-O3@g' SConstruct
%ifarch %{ix86}
OPTFLAGS_SSE="%{optflags} -ffast-math -msse -mfpmath=sse" \
perl -pi -e \
	'BEGIN { $s = join(", ", map { "'\''$_'\''" } "-funsigned-char", split(" ", $ENV{OPTFLAGS_SSE})) } s/extra_flags\s*=\s*\[.*\]$/extra_flags = [ $s ]/' SConstruct.sse
perl -pi -e 's@-O2@-O3@g' SConstruct.sse
%endif

# Fix pt_BR
sed -i "s,pt_br,pt_BR,g" bin/.blender/.Blanguages
mv bin/.blender/locale/pt_br bin/.blender/locale/pt_BR

%build
%ifarch %{ix86}
cp -p SConstruct SConstruct.std
cp -p SConstruct.sse SConstruct
scons
cp -p blender blender.sse
scons -c
cp -p SConstruct.std SConstruct
%endif
%if %build_debug
BUILD_BINARY=debug \
%endif
scons

# Build plugins
pushd release/plugins
   ln -s ../../source/blender/blenpluginapi include
   chmod +x bmake
   %make
popd

find ./test%{testver} -type f -print0|xargs -0 chmod 644
find ./test%{testver} -type d -print0|xargs -0 chmod 755 


%install
rm -rf %{buildroot}

install -m 755 %{SOURCE1} blender-wrapper
%ifarch %{ix86}
cat >> blender-wrapper <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	\${BLENDER_LIBDIR}/blender/blender "\$@"
else
	\${BLENDER_LIBDIR}/blender/blender.sse "\$@"
fi
EOF
%else
cat >> blender-wrapper <<EOF
\${BLENDER_LIBDIR}/blender/blender "\$@"
EOF
%endif

install -d -m755 \
		%{buildroot}%{_bindir} \
		%{buildroot}%{_libdir}/%{name} \
		%{buildroot}%{_datadir}

install -m755 blenderplayer %{buildroot}%{_bindir}
install -m755 blender %{buildroot}%{_libdir}/%{name}
%ifarch %{ix86}
install -m755 blender.sse %{buildroot}%{_libdir}/%{name}
%endif
install -m755 blender-wrapper %{buildroot}%{_bindir}/%{name}
sed -i "s,SPECDEFINED,%_libdir,g" %{buildroot}%{_bindir}/blender %{buildroot}%{_bindir}/%{name}
cp -p %{buildroot}%{_bindir}/blender %{buildroot}%{_bindir}/%{name}nodri
perl -pi -e 's@^([\t ])+\$\{BLENDER_LIBDIR\}/blender/blender@LIBGL_ALWAYS_INDIRECT=1 \$\{BLENDER_LIBDIR\}/blender/blender@g' %{buildroot}%{_bindir}/%{name}nodri

cp -a release/scripts %{buildroot}%{_libdir}/%{name}
cp -a bin/.blender/locale  %{buildroot}%{_datadir}
install -p -m644 bin/.blender/.Blanguages %{buildroot}%{_libdir}/%{name}
install -p -m644 bin/.blender/.bfont.ttf %{buildroot}%{_libdir}/%{name}
install -p -m644 release/VERSION %buildroot%_libdir/%{name}
install -p -m644 source/blender/python/api2_2x/doc/* %{buildroot}%{_libdir}/%{name}/scripts

install -d -m755 %{buildroot}%{_libdir}/%{name}/plugins/sequence
install -pD -m644 release/plugins/sequence/*.so %{buildroot}%{_libdir}/%{name}/plugins/sequence
install -d %{buildroot}%{_libdir}/%{name}/plugins/texture
install -pD -m644 release/plugins/texture/*.so %{buildroot}%{_libdir}/%{name}/plugins/texture

# menu
mkdir -p %{buildroot}%{_menudir}
cat > %{buildroot}%{_menudir}/%{name} <<EOF
?package(%{name}): command="%{_bindir}/%{name}" \
	needs="X11" \
	icon="%{name}.png" \
	section="Multimedia/Graphics" \
	title="Blender" \
	longtitle="A fully functional 3D modeling/rendering/animation package" \
	mimetypes="application/x-blender"
EOF
cat > %{buildroot}%{_menudir}/%{name}nodri <<EOF
?package(%{name}): command="%{_bindir}/%{name}nodri" \
	needs="X11" \
	icon="%{name}nodri.png" \
	section="Multimedia/Graphics" \
	title="Blender (No DRI)" \
	longtitle="A fully functional 3D modeling/rendering/animation package (with DRI disabled)"
EOF

# icons
install -m644 %{SOURCE11} -D %{buildroot}%{_miconsdir}/%{name}.png
install -m644 %{SOURCE12} -D %{buildroot}%{_iconsdir}/%{name}.png
install -m644 %{SOURCE13} -D %{buildroot}%{_liconsdir}/%{name}.png
tar xjf %{SOURCE14} -C %{buildroot}%{_iconsdir}

%clean
rm -rf %{buildroot}

%post
%{update_menus}

%postun
%{clean_menus}

%files
%defattr(-,root,root)
%doc README doc/*.txt test%{testver}
%{_bindir}/*
%{_menudir}/*
%{_datadir}/locale/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/scripts
%{_libdir}/%{name}/%{name}
%ifarch %{ix86}
%{_libdir}/%{name}/%{name}.sse
%endif
%{_libdir}/%{name}/.bfont.ttf
%{_libdir}/%{name}/.Blanguages
%{_libdir}/%{name}/VERSION
%{_libdir}/%{name}/scripts/*
%{_libdir}/%{name}/plugins/sequence
%{_libdir}/%{name}/plugins/texture
%{_miconsdir}/%{name}.png
%{_liconsdir}/%{name}.png
%{_iconsdir}/%{name}.png
%{_miconsdir}/%{name}nodri.png
%{_liconsdir}/%{name}nodri.png
%{_iconsdir}/%{name}nodri.png

%changelog
* Mon Jun 05 2006 Giuseppe Ghib <ghibo@mandriva.com> 2.41-4.1.20060mdk
- Force calling yafray trough library and not trough XML file (Patch3) as
  XML doesn't work anymore with yafray > 0.07, and anyway plugin it's better.
- Added yafray in Requires.
- Quote \$@ in wrapper.
- Added blendernodri wrapper to avoid blender's UI flashing problems
  with some card under DRI (e.g. Matrox).
- Updated svg2obj python script to 0.47.
- Rebuilt for 2006.0.

* Tue May 30 2006 Helio Chissini de Castro <helio@mandriva.com>
+ 2006-05-30 22:32:26 (31774)
- Fixed the mess did on svn versus regular upload. We should take more care in
  further operations.

* Mon May 29 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-05-29 14:36:37 (31646)
- renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

* Mon May 22 2006 Giuseppe Ghib <ghibo@mandriva.com> 2.41-3mdk
- Stronger optimization with %%optflags (thanks to Pixel).
- python-devel >= 2.4 in BuildRequires.

* Thu May 11 2006 Helio Chissini de Castro <helio@mandriva.com>
+ 2006-05-11 22:18:41 (27129)
- New wrapper. Blender plugins usually deal with a lot of tmp/inplace writing.
  So now user get their own .blender env created.
- Fixed locale translations.
- Fixed pt_BR potfile naming

* Thu May 11 2006 Helio Chissini de Castro <helio@mandriva.com>
+ 2006-05-11 16:46:37 (27113)
- New upstream release
- Finally we have blender internationalized, ann compiling in x86_64
- Physics engine ODE isn't compiling at this moment
- blenderplayer was reenabled, so game on again :-)

* Thu May 11 2006 Helio Chissini de Castro <helio@mandriva.com>
+ 2006-05-11 14:35:03 (27102)
- Still fixing my mess

* Thu May 11 2006 Helio Chissini de Castro <helio@mandriva.com>
+ 2006-05-11 14:34:26 (27101)
- Fix my mess

* Thu Apr 13 2006 Giuseppe Ghib <ghibo@mandriva.com> 2.40-2mdk
- Added tiff-devel to BuildRequires.

* Wed Dec 28 2005 Olivier Blin <oblin@mandriva.com> 2.40-1mdk
- New release 2.40

* Wed Aug 03 2005 Gustavo Pichorim Boiko <boiko@mandriva.com> 2.37a-1mdk
- Updated to version 2.37a
- Added blenderplayer (the standalone game player)
- Added some default python scripts for importing and exporting
- Added localization files to the package. They were put into the main package
  because blender doesn't automatically choose the language in the interface.

* Thu Jun  2 2005 Olivier Blin <oblin@mandriva.com> 2.37-1mdk
- 2.37 : http://www.blender3d.org/cms/Blender_2_37.496.0.html

* Fri Dec 24 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.36-1mdk
- 2.36

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 2.35-2mdk
- Rebuild for new python

* Tue Nov 16 2004 Olivier Blin <blino@mandrake.org> 2.35-1mdk
- 2.35 : http://www.blender3d.org/cms/Blender_2_35.482.0.html

* Fri Aug  6 2004 Olivier Blin <blino@mandrake.org> 2.34-1mdk
- 2.34 : http://www.blender3d.org/cms/Blender_2_34.319.0.html
- remove gcc/libstdc++ patches (fixed upstream)
- fix doc files list

* Wed Jun 23 2004 Olivier Blin <blino@mandrake.org> 2.33a-1mdk
- 2.33a (yeah, game engine is back)
- rediff Patch1
- more gcc 3.4 template fixes (Patch2)
- switch to scons build system

* Wed Jun 16 2004 Olivier Blin <blino@mandrake.org> 2.32-2mdk
- rebuilt for new libstdc++
- Added Patch0 to fix build with new libstdc++
- Added Patch1 to fix build with gcc 3.4

* Fri Apr 02 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.32-1mdk
- 2.32
- fix buildrequires (lib64..)
- don't bzip2 icons in src.rpm

* Tue Mar 02 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.31a-2mdk
- rebuild

* Fri Dec 05 2003 Lenny Cartier <lenny@mandrakesoft.com> 2.31a-1mdk
- 2.31a

* Mon Dec 01 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.31-1mdk
- Release: 2.31.

* Thu Nov 06 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.30-1mdk
- Release: 2.30.
- Removed Patch0, Patch1, no longer needed.

* Thu Sep 18 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.28a-3mdk
- Added Patch1 to fix crash on startup.

* Wed Sep 10 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.28a-2mdk
- Release: 2.28a.
- Removed old Patch0.
- Added Patch0 to fix junk lines in configure.
- Added python-imaging to Requires to avoid crash on startup.

* Wed Sep 03 2003 Olivier Blin <oliv.blin@laposte.net> 2.28a-1mdk
- 2.28a (bugfix release)
- fix changelog

* Fri Aug 08 2003 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.28-3mdk
- rebuild against python for real (me suckysucky long time, and not in a good way;)

* Thu Aug 07 2003 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.28-2mdk
- rebuild for new python

* Sat Jul 26 2003 Per yvind Karlsen <peroyvind@sintrax.net> 2.28-1mdk
- 2.2.8
- updated docs

* Fri Jul 25 2003 Per yvind Karlsen <peroyvind@sintrax.net> 2.27-2mdk
- rebuild
- change summary macro to avoid possible conflicts if we were to build debug package

* Tue May 20 2003 Per yvind Karlsen <peroyvind@sintrax.net> 2.27-1mdk
- 2.27
- quiet setup
- fixed buildrequires, also clutter .spec file with one line for each
- fix missing summary macro used in menu item
- a little macroisation
- regenerate Patch0
- added some docs

* Wed Feb 12 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.26-1mdk
- Updated to release 2.26.
- Disabled gameblender building (problems with libopenal).
- Added Patch0 to avoid library conflicts during building.

* Mon Nov 25 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.25b-3mdk
- Use .png extensions in %files list.

* Sun Nov 24 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.25b-2mdk
- Merged with prepared SPEC file.
- Build static version.
- Changed icons.
- Added some BuildRequires.
- Revert to static.
- Added Url for Source0, so to understand which source is used.

* Sat Nov 23 2002 Per yvind Karlsen <peroyvind@sintrax.net> 2.25-b.1mdk
- Initial relase
